package com.goldenwater.slaj.sins.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.sins.mapper.RelSinsGroupToExpeMapper;
import com.goldenwater.slaj.sins.domain.RelSinsGroupToExpe;
import com.goldenwater.slaj.sins.service.IRelSinsGroupToExpeService;

@Service
public class RelSinsGroupToExpeServiceImpl implements IRelSinsGroupToExpeService {
    @Autowired
    private RelSinsGroupToExpeMapper relSinsGroupToExpeMapper;

    @Override
    public RelSinsGroupToExpe selectRelSinsGroupToExpeByGuid(String guid) { return relSinsGroupToExpeMapper.selectRelSinsGroupToExpeByGuid(guid); }
    @Override
    public List<RelSinsGroupToExpe> selectRelSinsGroupToExpeList(RelSinsGroupToExpe relSinsGroupToExpe) { return relSinsGroupToExpeMapper.selectRelSinsGroupToExpeList(relSinsGroupToExpe); }
    @Override
    public int insertRelSinsGroupToExpe(RelSinsGroupToExpe relSinsGroupToExpe) { return relSinsGroupToExpeMapper.insertRelSinsGroupToExpe(relSinsGroupToExpe); }
    @Override
    public int updateRelSinsGroupToExpe(RelSinsGroupToExpe relSinsGroupToExpe) { return relSinsGroupToExpeMapper.updateRelSinsGroupToExpe(relSinsGroupToExpe); }
    @Override
    public int deleteRelSinsGroupToExpeByGuid(String guid) { return relSinsGroupToExpeMapper.deleteRelSinsGroupToExpeByGuid(guid); }
    @Override
    public int deleteRelSinsGroupToExpeByGuids(String[] guids) { return relSinsGroupToExpeMapper.deleteRelSinsGroupToExpeByGuids(guids); }
}
